@@ -279,7 +279,7 @@ class DriftCorrectionBehavior:
             # this method must be thread safe
             # start with the context frame parameters and adjust for the drift region
             frame_parameters = copy.deepcopy(self.__scan_frame_parameters)
-            context_size = frame_parameters.size.to_float_size()
+            context_size = frame_parameters.pixel_size.to_float_size()
             drift_channel_id = self.__scan_hardware_source.drift_channel_id
             drift_region = self.__scan_hardware_source.drift_region
             drift_rotation = self.__scan_hardware_source.drift_rotation
