@@ -631,7 +631,7 @@ class MultiAcquireController:
                                            include_shift_delay: bool = False) -> float:
         total_time = 0
         if scan_parameters is not None:
-            scan_size = scan_parameters.size
+            scan_size = scan_parameters.pixel_size
         else:
             scan_size = Geometry.IntSize(1, 1)
         for parameters in spectrum_parameters:
