@@ -106,7 +106,7 @@ class ScanContext:
         self.rotation_rad: typing.Optional[float] = None
 
     def __repr__(self) -> str:
-        if self.fov_nm and self.size and self.rotation_rad:
+        if self.fov_nm and self.size and self.rotation_rad is not None:
             return f"{self.size} {self.fov_nm}nm {math.degrees(self.rotation_rad)}deg"
         else:
             return "NO CONTEXT"
@@ -190,6 +190,7 @@ class STEMController(Observable.Observable):
     def __init__(self) -> None:
         super().__init__()
         self.__probe_position: typing.Optional[Geometry.FloatPoint] = None
+        self.__last_probe_position = Geometry.FloatPoint(0.5, 0.5)
         self.__probe_state_stack = list()  # parked, or scanning
         self.__probe_state_stack.append("parked")
         self.__scan_context = ScanContext()
@@ -216,6 +217,7 @@ class STEMController(Observable.Observable):
 
     def reset(self) -> None:
         self.__probe_position = None
+        self.__last_probe_position = Geometry.FloatPoint(y=0.5, x=0.5)
         self.__probe_state_stack.clear()
         self.__probe_state_stack.append("parked")
         self.__scan_context.clear()
@@ -412,10 +414,16 @@ class STEMController(Observable.Observable):
             self.scan_context_changed_event.fire()
 
     def _confirm_scan_context(self, size: Geometry.IntSize, center_nm: Geometry.FloatPoint, fov_nm: float, rotation_rad: float) -> None:
-        current_context = copy.deepcopy(self.scan_context)
-        current_context.update(size, center_nm, fov_nm, rotation_rad)
-        if current_context != self.scan_context:
+        new_context = copy.deepcopy(self.scan_context)
+        new_context.update(size, center_nm, fov_nm, rotation_rad)
+        new_aspect_ratio = size.aspect_ratio
+        current_aspect_ratio = self.scan_context.size.aspect_ratio if self.scan_context.size else 0.0
+
+        if new_context.fov_nm != self.scan_context.fov_nm or new_context.center_nm != self.scan_context.center_nm or new_context.rotation_rad != self.scan_context.rotation_rad or new_aspect_ratio != current_aspect_ratio:
             self._clear_scan_context()
+        else:
+            # ensure size is updated
+            self.scan_context.update(size, center_nm, fov_nm, rotation_rad)
 
     @property
     def probe_position(self) -> typing.Optional[Geometry.FloatPoint]:
@@ -429,6 +437,7 @@ class STEMController(Observable.Observable):
             value = Geometry.FloatPoint(y=max(min(value.y, 1.0), 0.0), x=max(min(value.x, 1.0), 0.0))
         if self.probe_position != value:
             self.__probe_position = value
+            self.__last_probe_position = self.__probe_position if self.__probe_position else self.__last_probe_position
             self.notify_property_changed("probe_position")
             # update the probe position for listeners and also explicitly update for probe_graphic_connections.
             self.probe_state_changed_event.fire(self.probe_state, self.probe_position)
@@ -440,7 +449,7 @@ class STEMController(Observable.Observable):
         """Validate the probe position.
 
         This is called when the user switches from not controlling to controlling the position."""
-        self.set_probe_position(Geometry.FloatPoint(y=0.5, x=0.5))
+        self.set_probe_position(self.__last_probe_position)
 
     @property
     def probe_state(self) -> str:
@@ -700,13 +709,20 @@ class GraphicSetController:
 
 
 class DisplayItemListModel(Observable.Observable):
-    """Make an observable list model from the item source with a list as the item."""
+    """Make an observable list model from the item source with a list as the item.
 
-    def __init__(self, document_model: DocumentModel.DocumentModel, item_key: str,
+    item_inserted/item_removed notifications will always occur on the main thread.
+    """
+
+    def __init__(self,
+                 document_model: DocumentModel.DocumentModel,
+                 call_soon_threadsafe: typing.Callable[[typing.Callable[..., None]], None],
+                 item_key: str,
                  predicate: typing.Callable[[DisplayItem.DisplayItem], bool],
                  change_event: typing.Optional[Event.Event] = None):
         super().__init__()
         self.__document_model = document_model
+        self.__call_soon_threadsafe = call_soon_threadsafe
         self.__item_key = item_key
         self.__predicate = predicate
         self.__items : typing.List[DisplayItem.DisplayItem] = list()
@@ -737,6 +753,7 @@ class DisplayItemListModel(Observable.Observable):
         self.__item_removed_listener = typing.cast(typing.Any, None)
         self.__document_close_listener.close()
         self.__document_close_listener = typing.cast(typing.Any, None)
+        self.__call_soon_threadsafe = typing.cast(typing.Any, None)
         self.__document_model = typing.cast(typing.Any, None)
 
     def __item_inserted(self, key: str, display_item: DisplayItem.DisplayItem, index: int) -> None:
@@ -760,7 +777,7 @@ class DisplayItemListModel(Observable.Observable):
             return self.items
         raise AttributeError()
 
-    def refilter(self) -> None:
+    def __refilter(self) -> None:
         self.item_set = set(self.__items)
         for display_item in self.__document_model.display_items:
             if self.__predicate(display_item):
@@ -776,26 +793,32 @@ class DisplayItemListModel(Observable.Observable):
                     self.__items.pop(index)
                     self.notify_remove_item(self.__item_key, display_item, index)
 
+    def refilter(self) -> None:
+        if threading.current_thread() == threading.main_thread():
+            self.__refilter()
+        else:
+            self.__call_soon_threadsafe(self.__refilter)
+
     def clean(self, graphic_id: str) -> None:
         display_items = self.__document_model.display_items
         for display_item in display_items:
-            for graphic in display_item.graphics:
-                if graphic.graphic_id == graphic_id:
-                    display_item.remove_graphic(graphic).close()
+            if self.__predicate(display_item):
+                for graphic in display_item.graphics:
+                    if graphic.graphic_id == graphic_id:
+                        display_item.remove_graphic(graphic).close()
 
-def make_scan_display_item_list_model(document_model: DocumentModel.DocumentModel, stem_controller: STEMController) -> DisplayItemListModel:
+def make_scan_display_item_list_model(document_model: DocumentModel.DocumentModel, stem_controller: STEMController, call_soon_threadsafe: typing.Callable[[typing.Callable[..., None]], None]) -> DisplayItemListModel:
     def is_scan_context_display_item(display_item: DisplayItem.DisplayItem) -> bool:
         scan_controller = stem_controller.scan_controller
         if scan_controller:
-            for data_channel in scan_controller.data_channels:
-                channel_id = data_channel.channel_id
-                if channel_id and not channel_id.endswith("subscan") and channel_id != "drift":
-                    data_item_channel_reference = document_model.get_data_item_channel_reference(scan_controller.hardware_source_id, channel_id)
-                    if data_item_channel_reference and data_item_channel_reference.display_item == display_item:
-                        return True
+            context_data_channels = scan_controller.get_context_data_channels()
+            for data_channel in context_data_channels:
+                data_item_channel_reference = document_model.get_data_item_channel_reference(scan_controller.hardware_source_id, data_channel.channel_id)
+                if data_item_channel_reference and data_item_channel_reference.display_item == display_item:
+                    return True
         return False
 
-    return DisplayItemListModel(document_model, "display_items", is_scan_context_display_item, stem_controller.scan_context_data_items_changed_event)
+    return DisplayItemListModel(document_model, call_soon_threadsafe, "display_items", is_scan_context_display_item, stem_controller.scan_context_data_items_changed_event)
 
 
 class EventLoopMonitor:
@@ -834,7 +857,8 @@ class ProbeView(EventLoopMonitor, AbstractGraphicSetHandler, DocumentModel.Abstr
         self.__class__.count += 1
         self.__stem_controller = stem_controller
         self.__document_model = document_model
-        self.__scan_display_items_model = make_scan_display_item_list_model(document_model, stem_controller)
+        self.__scan_display_items_model = make_scan_display_item_list_model(document_model, stem_controller, self._call_soon_threadsafe)
+        self.__display_item_inserted_event_listener = self.__scan_display_items_model.item_inserted_event.listen(ReferenceCounting.weak_partial(ProbeView.__display_item_inserted, self))
         self.__project_loaded_event_listener = document_model.project_loaded_event.listen(ReferenceCounting.weak_partial(ProbeView.__refilter_scan_display_items, self))
         self.__graphic_set = GraphicSetController(self)
         # note: these property changed listeners can all possibly be fired from a thread.
@@ -856,6 +880,7 @@ class ProbeView(EventLoopMonitor, AbstractGraphicSetHandler, DocumentModel.Abstr
         self.__scan_display_items_model = typing.cast(typing.Any, None)
         self.__document_model = typing.cast(typing.Any, None)
         self.__stem_controller = typing.cast(typing.Any, None)
+        self.__display_item_inserted_event_listener = typing.cast(typing.Any, None)
         self.__project_loaded_event_listener = typing.cast(typing.Any, None)
         self.__class__.count -= 1
 
@@ -881,6 +906,11 @@ class ProbeView(EventLoopMonitor, AbstractGraphicSetHandler, DocumentModel.Abstr
         self.__scan_display_items_model.refilter()
         self.__update_probe_state(stem_controller.probe_state, stem_controller.probe_position)
 
+    def __display_item_inserted(self, name: str, item: DisplayItem.DisplayItem, index: int) -> None:
+        if name == "display_items":
+            stem_controller = self.__stem_controller
+            self.__update_probe_state(stem_controller.probe_state, stem_controller.probe_position)
+
     # implement methods for the graphic set handler
 
     def _graphic_removed(self, probe_graphic: Graphics.Graphic) -> None:
@@ -923,7 +953,8 @@ class SubscanView(EventLoopMonitor, AbstractGraphicSetHandler, DocumentModel.Abs
         self.__class__.count += 1
         self.__stem_controller = stem_controller
         self.__document_model = document_model
-        self.__scan_display_items_model = make_scan_display_item_list_model(document_model, stem_controller)
+        self.__scan_display_items_model = make_scan_display_item_list_model(document_model, stem_controller, self._call_soon_threadsafe)
+        self.__display_item_inserted_event_listener = self.__scan_display_items_model.item_inserted_event.listen(ReferenceCounting.weak_partial(SubscanView.__display_item_inserted, self))
         self.__project_loaded_event_listener = document_model.project_loaded_event.listen(ReferenceCounting.weak_partial(SubscanView.__refilter_scan_display_items, self))
         self.__graphic_set = GraphicSetController(self)
         # note: these property changed listeners can all possibly be fired from a thread.
@@ -942,6 +973,7 @@ class SubscanView(EventLoopMonitor, AbstractGraphicSetHandler, DocumentModel.Abs
         self.__scan_display_items_model = typing.cast(typing.Any, None)
         self.__document_model = typing.cast(typing.Any, None)
         self.__stem_controller = typing.cast(typing.Any, None)
+        self.__display_item_inserted_event_listener = typing.cast(typing.Any, None)
         self.__project_loaded_event_listener = typing.cast(typing.Any, None)
         self.__class__.count -= 1
 
@@ -976,6 +1008,10 @@ class SubscanView(EventLoopMonitor, AbstractGraphicSetHandler, DocumentModel.Abs
         self.__scan_display_items_model.refilter()
         self.__update_subscan_region()
 
+    def __display_item_inserted(self, name: str, item: DisplayItem.DisplayItem, index: int) -> None:
+        if name == "display_items":
+            self.__update_subscan_region()
+
     # implement methods for the graphic set handler
 
     def _graphic_removed(self, subscan_graphic: Graphics.Graphic) -> None:
@@ -1025,7 +1061,8 @@ class LineScanView(EventLoopMonitor, AbstractGraphicSetHandler, DocumentModel.Ab
         self.__class__.count += 1
         self.__stem_controller = stem_controller
         self.__document_model = document_model
-        self.__scan_display_items_model = make_scan_display_item_list_model(document_model, stem_controller)
+        self.__scan_display_items_model = make_scan_display_item_list_model(document_model, stem_controller, self._call_soon_threadsafe)
+        self.__display_item_inserted_event_listener = self.__scan_display_items_model.item_inserted_event.listen(ReferenceCounting.weak_partial(LineScanView.__display_item_inserted, self))
         self.__project_loaded_event_listener = document_model.project_loaded_event.listen(ReferenceCounting.weak_partial(LineScanView.__refilter_scan_display_items, self))
         self.__graphic_set = GraphicSetController(self)
         # note: these property changed listeners can all possibly be fired from a thread.
@@ -1043,6 +1080,7 @@ class LineScanView(EventLoopMonitor, AbstractGraphicSetHandler, DocumentModel.Ab
         self.__scan_display_items_model = typing.cast(typing.Any, None)
         self.__document_model = typing.cast(typing.Any, None)
         self.__stem_controller = typing.cast(typing.Any, None)
+        self.__display_item_inserted_event_listener = typing.cast(typing.Any, None)
         self.__project_loaded_event_listener = typing.cast(typing.Any, None)
         self.__class__.count -= 1
 
@@ -1070,6 +1108,10 @@ class LineScanView(EventLoopMonitor, AbstractGraphicSetHandler, DocumentModel.Ab
         self.__scan_display_items_model.refilter()
         self.__update_line_scan_vector()
 
+    def __display_item_inserted(self, name: str, item: DisplayItem.DisplayItem, index: int) -> None:
+        if name == "display_items":
+            self.__update_line_scan_vector()
+
     # implement methods for the graphic set handler
 
     def _graphic_removed(self, line_scan_graphic: Graphics.Graphic) -> None:
@@ -1116,7 +1158,8 @@ class DriftView(EventLoopMonitor):
         self.__class__.count += 1
         self.__stem_controller = stem_controller
         self.__document_model = document_model
-        self.__scan_display_items_model = make_scan_display_item_list_model(document_model, stem_controller)
+        self.__scan_display_items_model = make_scan_display_item_list_model(document_model, stem_controller, self._call_soon_threadsafe)
+        self.__display_item_inserted_event_listener = self.__scan_display_items_model.item_inserted_event.listen(ReferenceCounting.weak_partial(DriftView.__display_item_inserted, self))
         self.__project_loaded_event_listener = document_model.project_loaded_event.listen(ReferenceCounting.weak_partial(DriftView.__clean, self))
         self.__graphic_display_item : typing.Optional[DisplayItem.DisplayItem] = None
         self.__graphic : typing.Optional[Graphics.RectangleGraphic] = None
@@ -1144,6 +1187,7 @@ class DriftView(EventLoopMonitor):
         self.__scan_display_items_model = typing.cast(typing.Any, None)
         self.__document_model = typing.cast(typing.Any, None)
         self.__stem_controller = typing.cast(typing.Any, None)
+        self.__display_item_inserted_event_listener = typing.cast(typing.Any, None)
         self.__project_loaded_event_listener = typing.cast(typing.Any, None)
         self.__class__.count -= 1
 
@@ -1251,6 +1295,10 @@ class DriftView(EventLoopMonitor):
         self.__scan_display_items_model.clean("drift")
         self.__update_drift_region()
 
+    def __display_item_inserted(self, name: str, item: DisplayItem.DisplayItem, index: int) -> None:
+        if name == "display_items":
+            self.__update_drift_region()
+
 
 class ScanContextController:
     """Manage probe view, subscan, and drift area for each instrument (STEMController) that gets registered."""
