@@ -406,7 +406,7 @@ class TestSynchronizedAcquisitionClass(unittest.TestCase):
             self.assertEqual(100.0, Metadata.get_metadata_value(metadata, "stem.scan.fov_nm"))
             self.assertIsNone(Metadata.get_metadata_value(metadata, "stem.scan.pixel_time_us"))
             self.assertEqual(0.0, Metadata.get_metadata_value(metadata, "stem.scan.rotation"))
-            self.assertIsNotNone(uuid.UUID(Metadata.get_metadata_value(metadata, "stem.scan.scan_id")))
+            # note: scan_id is not required here since there will be multiple scans.
             self.assertIsNone(Metadata.get_metadata_value(metadata, "stem.scan.line_time_us"))
             self.assertEqual((4, 4), metadata["scan"]["scan_context_size"])
             self.assertEqual((4, 4), metadata["scan"]["scan_size"])
@@ -1058,12 +1058,11 @@ class TestSynchronizedAcquisitionClass(unittest.TestCase):
             scan_acquisition_controller._wait()
             updated_frame_parameters = scan_hardware_source.get_current_frame_parameters().as_dict()
             for k in list(updated_frame_parameters.keys()):
-                if k not in ("size", "center_nm", "pixel_time_us", "fov_nm", "rotation_rad", "flyback_time_us"):
+                if k not in ("pixel_size", "center_nm", "pixel_time_us", "fov_nm", "rotation_rad", "flyback_time_us"):
                     updated_frame_parameters.pop(k)
-            scan_hardware_source._update_frame_parameters_test(0, scan_base.ScanFrameParameters(updated_frame_parameters))
+            scan_hardware_source.set_frame_parameters(0, scan_base.ScanFrameParameters(updated_frame_parameters))
             current_frame_parameters = scan_hardware_source.get_current_frame_parameters()
             # import pprint; print(pprint.pformat(dict(current_frame_parameters)))
-            self.assertIsNotNone(current_frame_parameters.channel_modifier)
             self.assertIsNotNone(current_frame_parameters.subscan_fractional_center)
             self.assertIsNotNone(current_frame_parameters.subscan_fractional_size)
             self.assertIsNotNone(current_frame_parameters.subscan_pixel_size)
