@@ -383,7 +383,6 @@ class MultiAcquirePanelDelegate:
                     scan_frame_parameters = scan_controller.get_current_frame_parameters()
                     camera_frame_parameters.exposure_ms = multi_acquire_parameters[current_parameters_index]['exposure_ms']
                     camera_frame_parameters.processing = multi_acquire_settings['processing']
-                    scan_frame_parameters.scan_id = scan_frame_parameters.scan_id or uuid.uuid4()
                     grab_synchronized_info = scan_controller.grab_synchronized_get_info(
                         scan_frame_parameters=scan_frame_parameters,
                         camera=camera,
@@ -578,10 +577,10 @@ class MultiAcquirePanelDelegate:
         time_estimate_row.add_spacing(6)
         self.multi_acquire_controller.stem_controller = self.stem_controller
         self.multi_acquire_controller.scan_controller = self.scan_controller
-        def frame_parameters_changed(profile_index: int, frame_parameters: scan_base.ScanFrameParameters) -> None:
+        def frame_parameters_changed(frame_parameters: scan_base.ScanFrameParameters) -> None:
             self.update_time_estimate()
         if self.scan_controller:
-            self.__scan_frame_parameters_changed_event_listener = self.scan_controller.frame_parameters_changed_event.listen(frame_parameters_changed)
+            self.__scan_frame_parameters_changed_event_listener = self.scan_controller.scan_settings.current_frame_parameters_changed_event.listen(frame_parameters_changed)
         self.update_camera_list()
 
         self.start_button = ui.create_push_button_widget('Start MultiAcquire')
@@ -877,7 +876,7 @@ class MultiAcquirePanelDelegate:
                 self.settings_changed()
 
             def about_to_close(self, geometry: str, state: str) -> None:
-                if self.on_reject:
+                if callable(self.on_reject):
                     self.on_reject()
                 super().about_to_close(geometry, state)
                 self.checkboxes = {}
